package org.opengroup.osdu.notification.auth.factory;

import org.junit.Before;
import org.junit.Test;
import org.junit.runner.RunWith;
import org.mockito.InjectMocks;
import org.mockito.Mock;
import org.mockito.MockitoAnnotations;
import org.mockito.junit.MockitoJUnitRunner;
import org.opengroup.osdu.core.common.logging.JaxRsDpsLog;
import org.opengroup.osdu.core.common.model.http.AppException;
import org.opengroup.osdu.notification.auth.GsaAuth;
import org.opengroup.osdu.notification.auth.HmacAuth;
import org.opengroup.osdu.notification.auth.interfaces.SecretAuth;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertTrue;


@RunWith(MockitoJUnitRunner.class)
public class AuthFactoryTest {

    @Mock
    private HmacAuth hmacAuth;

    @Mock
    private GsaAuth gsaAuth;

    @InjectMocks
    AuthFactory authFactory;

    @Before
    public void setup(){
        MockitoAnnotations.initMocks(AuthFactoryTest.this);
    }

    @Test(expected = AppException.class)
    public void getSecretAuthTest_invalidType(){
        authFactory.getSecretAuth("invalid");
    }

    @Test
    public void getSecretAuthTest_gsaAuth(){
        SecretAuth secretAuth = authFactory.getSecretAuth("GSA");
        assertTrue(secretAuth instanceof GsaAuth);
    }

    @Test
    public void getSecretAuthTest_hmacAuth(){
        SecretAuth secretAuth = authFactory.getSecretAuth("HMAC");
        assertTrue(secretAuth instanceof HmacAuth);
    }
}
